@@ -566,7 +566,7 @@ private slots:
     void slotItemContextMenuRequested(int index, const QPointF& pos);
     void slotViewContextMenuRequested(const QPointF& pos);
     void slotHeaderContextMenuRequested(const QPointF& pos);
-    void slotHeaderColumnWidthChanged(const QByteArray& role, qreal current, qreal previous);
+    void slotHeaderColumnWidthChangeFinished(const QByteArray& role, qreal current);
     void slotItemHovered(int index);
     void slotItemUnhovered(int index);
     void slotItemDropEvent(int index, QGraphicsSceneDragDropEvent* event);
